__title__ = 'Eve-Azure-Auth'
__description__ = ''
__url__ = 'https://github.com/ateliedocodigo/eve-azure-auth'
__version__ = '0.2.0'
__author__ = 'LuisComS'
__author_email__ = 'luiscoms@ateliedocodigo.com.br'
__copyright__ = 'Copyright 2020 Ateliê do Código'
